@@ -52,12 +52,12 @@ class TimeSeriesParametersDataCheck(DataCheck):
             >>> y = pd.Series([i for i in range(100)])
             ...
             >>> problem_config = {"gap": 7, "max_delay": 2, "forecast_horizon": 12, "time_index": "dates"}
-            >>> target_leakage_check = TimeSeriesParametersDataCheck(problem_configuration=problem_config, n_splits=4)
-            >>> assert target_leakage_check.validate(X, y) == [
+            >>> ts_parameters_check = TimeSeriesParametersDataCheck(problem_configuration=problem_config, n_splits=7)
+            >>> assert ts_parameters_check.validate(X, y) == [
             ...     {
-            ...         "message": "Since the data has 100 observations and n_splits=4, the smallest "
-            ...                    "split would have 20 observations. Since 21 (gap + max_delay + forecast_horizon)"
-            ...                    " >= 20, then at least one of the splits would be empty by the time it reaches "
+            ...         "message": "Since the data has 100 observations, n_splits=7, and a forecast horizon of 12, the smallest "
+            ...                    "split would have 16 observations. Since 21 (gap + max_delay + forecast_horizon)"
+            ...                    " >= 16, then at least one of the splits would be empty by the time it reaches "
             ...                    "the pipeline. Please use a smaller number of splits, reduce one or more these "
             ...                    "parameters, or collect more data.",
             ...         "data_check_name": "TimeSeriesParametersDataCheck",
@@ -67,9 +67,9 @@ class TimeSeriesParametersDataCheck(DataCheck):
             ...             "columns": None,
             ...             "rows": None,
             ...             "max_window_size": 21,
-            ...             "min_split_size": 20,
+            ...             "min_split_size": 16,
             ...             "n_obs": 100,
-            ...             "n_splits": 4
+            ...             "n_splits": 7
             ...         },
             ...         "action_options": []
             ...     }
@@ -77,7 +77,6 @@ class TimeSeriesParametersDataCheck(DataCheck):
 
         """
         messages = []
-
         validation = are_ts_parameters_valid_for_split(
             gap=self.gap,
             max_delay=self.max_delay,
@@ -97,6 +96,6 @@ class TimeSeriesParametersDataCheck(DataCheck):
                         "n_obs": validation.n_obs,
                         "n_splits": validation.n_splits,
                     },
-                ).to_dict()
+                ).to_dict(),
             )
         return messages
