@@ -1,13 +1,17 @@
 """EvalML standard and custom objectives."""
-from .binary_classification_objective import BinaryClassificationObjective
-from .cost_benefit_matrix import CostBenefitMatrix
-from .fraud_cost import FraudCost
-from .lead_scoring import LeadScoring
-from .sensitivity_low_alert import SensitivityLowAlert
-from .multiclass_classification_objective import MulticlassClassificationObjective
-from .objective_base import ObjectiveBase
-from .regression_objective import RegressionObjective
-from .standard_metrics import (
+from evalml.objectives.binary_classification_objective import (
+    BinaryClassificationObjective,
+)
+from evalml.objectives.cost_benefit_matrix import CostBenefitMatrix
+from evalml.objectives.fraud_cost import FraudCost
+from evalml.objectives.lead_scoring import LeadScoring
+from evalml.objectives.sensitivity_low_alert import SensitivityLowAlert
+from evalml.objectives.multiclass_classification_objective import (
+    MulticlassClassificationObjective,
+)
+from evalml.objectives.objective_base import ObjectiveBase
+from evalml.objectives.regression_objective import RegressionObjective
+from evalml.objectives.standard_metrics import (
     AUC,
     F1,
     MAE,
@@ -44,7 +48,7 @@ from .standard_metrics import (
     RecallMicro,
     RecallWeighted,
 )
-from .utils import (
+from evalml.objectives.utils import (
     get_objective,
     get_core_objectives,
     get_all_objective_names,
