@@ -1,5 +1,5 @@
 """EvalML pipelines."""
-from .components import (
+from evalml.pipelines.components import (
     Estimator,
     OneHotEncoder,
     TargetEncoder,
@@ -45,15 +45,19 @@ from .components import (
     TimeSeriesRegularizer,
 )
 
-from .component_graph import ComponentGraph
-from .pipeline_base import PipelineBase
-from .classification_pipeline import ClassificationPipeline
-from .binary_classification_pipeline import BinaryClassificationPipeline
-from .multiclass_classification_pipeline import MulticlassClassificationPipeline
-from .regression_pipeline import RegressionPipeline
-from .time_series_classification_pipelines import (
+from evalml.pipelines.component_graph import ComponentGraph
+from evalml.pipelines.pipeline_base import PipelineBase
+from evalml.pipelines.classification_pipeline import ClassificationPipeline
+from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline
+from evalml.pipelines.multiclass_classification_pipeline import (
+    MulticlassClassificationPipeline,
+)
+from evalml.pipelines.regression_pipeline import RegressionPipeline
+from evalml.pipelines.time_series_classification_pipelines import (
     TimeSeriesClassificationPipeline,
     TimeSeriesBinaryClassificationPipeline,
     TimeSeriesMulticlassClassificationPipeline,
 )
-from .time_series_regression_pipeline import TimeSeriesRegressionPipeline
+from evalml.pipelines.time_series_regression_pipeline import (
+    TimeSeriesRegressionPipeline,
+)
