@@ -1,3 +1,4 @@
+"""Support Vector Machine Classifier."""
 import numpy as np
 from sklearn.svm import SVC
 from skopt.space import Real
@@ -8,10 +9,9 @@ from evalml.problem_types import ProblemTypes
 
 
 class SVMClassifier(Estimator):
-    """
-    Support Vector Machine Classifier.
+    """Support Vector Machine Classifier.
 
-    Arguments:
+    Args:
         C (float): The regularization parameter. The strength of the regularization is inversely proportional to C.
             Must be strictly positive. The penalty is a squared l2 penalty. Defaults to 1.0.
         kernel ({"poly", "rbf", "sigmoid"}): Specifies the kernel type to be used in the algorithm. Defaults to "rbf".
@@ -66,13 +66,19 @@ class SVMClassifier(Estimator):
         parameters.update(kwargs)
         svm_classifier = SVC(random_state=random_seed, **parameters)
         super().__init__(
-            parameters=parameters, component_obj=svm_classifier, random_seed=random_seed
+            parameters=parameters,
+            component_obj=svm_classifier,
+            random_seed=random_seed,
         )
 
     @property
     def feature_importance(self):
         """Feature importance only works with linear kernels.
-        If the kernel isn't linear, we return a numpy array of zeros
+
+        If the kernel isn't linear, we return a numpy array of zeros.
+
+        Returns:
+            Feature importance of fitted SVM classifier or a numpy array of zeroes if the kernel is not linear.
         """
         if self._parameters["kernel"] != "linear":
             return np.zeros(self._component_obj.n_features_in_)
