@@ -5,10 +5,7 @@ from skopt.space import Integer, Real
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components.estimators import Estimator
 from evalml.problem_types import ProblemTypes
-from evalml.utils.gen_utils import (
-    _rename_column_names_to_numeric,
-    import_or_raise,
-)
+from evalml.utils.gen_utils import _rename_column_names_to_numeric, import_or_raise
 
 
 class XGBoostRegressor(Estimator):
@@ -77,7 +74,9 @@ class XGBoostRegressor(Estimator):
         xgb = import_or_raise("xgboost", error_msg=xgb_error_msg)
         xgb_regressor = xgb.XGBRegressor(random_state=random_seed, **parameters)
         super().__init__(
-            parameters=parameters, component_obj=xgb_regressor, random_seed=random_seed
+            parameters=parameters,
+            component_obj=xgb_regressor,
+            random_seed=random_seed,
         )
 
     def fit(self, X, y=None):
