@@ -2,6 +2,8 @@
 import copy
 from abc import abstractmethod
 
+from woodwork.logical_types import IntegerNullable
+
 from evalml.pipelines.components.transformers import Transformer
 from evalml.utils.woodwork_utils import infer_feature_types
 
@@ -58,6 +60,24 @@ class BaseSampler(Transformer):
             pd.DataFrame, pd.Series: Prepared X and y data as pandas types
         """
         X = infer_feature_types(X)
+        int_nullable_cols = X.ww.select(IntegerNullable).columns
+        if len(int_nullable_cols) > 0:
+            try:
+                X = X.astype(
+                    {
+                        null_col: int
+                        for null_col in X.ww.select(IntegerNullable).columns
+                    },
+                )
+            except ValueError:
+                X = X.astype(
+                    {
+                        null_col: float
+                        for null_col in X.ww.select(IntegerNullable).columns
+                    },
+                )
+            X.ww.init(schema=X.ww.schema)
+
         if y is None:
             raise ValueError("y cannot be None")
         y = infer_feature_types(y)
