@@ -263,11 +263,20 @@ def test_evalml_algo_search_hyperparameters(
     X_y_categorical_classification,
 ):
     X, y = X_y_categorical_classification
-    X.ww.init()
     cat_cols = list(X.ww.select("categorical").columns)
-    mock_get_names.return_value = ["0", "1", "2", "Sex_male", "Embarked_S"]
+    mock_get_names.return_value = [
+        "0",
+        "1",
+        "2",
+        "Sex_male",
+        "Ticket_A/5 21171",
+        "C85",
+        "Embarked_S",
+    ]
     mock_get_feature_provenance.return_value = {
         "Sex": ["Sex_male"],
+        "Ticket": ["Ticket_A/5 21171"],
+        "Cabin": ["C85"],
         "Embarked": ["Embarked_S"],
     }
 
@@ -328,10 +337,8 @@ def test_default_algo_drop_columns(mock_get_names, columns, X_y_binary):
     X, y = X_y_binary
     mock_get_names.return_value = ["0", "1", "2"]
 
-    X = pd.DataFrame(X)
     for col in columns:
-        X[col] = pd.Series(range(len(X)))
-    X.ww.init()
+        X.ww[col] = pd.Series(range(len(X)))
     X.ww.set_types({col: "Unknown" for col in columns})
 
     algo = DefaultAlgorithm(X, y, ProblemTypes.BINARY, sampler_name=None)
@@ -358,7 +365,9 @@ def test_default_algo_drop_columns(mock_get_names, columns, X_y_binary):
                 assert pipeline.parameters[component_name]["columns"] == columns
 
 
-def test_make_split_pipeline(X_y_binary):
+@pytest.mark.parametrize("sampler", ["Oversampler", None])
+@pytest.mark.parametrize("features", [True, False])
+def test_make_split_pipeline(sampler, features, X_y_binary):
     X, y = X_y_binary
 
     X = pd.DataFrame(X)
@@ -369,22 +378,37 @@ def test_make_split_pipeline(X_y_binary):
     X["B"] = "b"
     X["C"] = "c"
 
-    algo = DefaultAlgorithm(X, y, ProblemTypes.BINARY, sampler_name=None)
+    algo = DefaultAlgorithm(
+        X,
+        y,
+        ProblemTypes.BINARY,
+        sampler_name=sampler,
+        features=features,
+    )
     algo._selected_cols = ["1", "2", "3"]
     algo._selected_cat_cols = ["A", "B", "C"]
     pipeline = algo._make_split_pipeline(RandomForestClassifier, "test_pipeline")
-    compute_order = [
-        "Label Encoder",
-        "Categorical Pipeline - Select Columns Transformer",
-        "Categorical Pipeline - Label Encoder",
-        "Categorical Pipeline - Imputer",
-        "Categorical Pipeline - One Hot Encoder",
-        "Numeric Pipeline - Select Columns By Type Transformer",
-        "Numeric Pipeline - Label Encoder",
-        "Numeric Pipeline - Imputer",
-        "Numeric Pipeline - Select Columns Transformer",
-        "Random Forest Classifier",
-    ]
+    compute_order = ["Label Encoder"]
+    if features:
+        compute_order.extend(["DFS Transformer"])
+    compute_order.extend(
+        [
+            "Categorical Pipeline - Select Columns Transformer",
+            "Categorical Pipeline - Label Encoder",
+            "Categorical Pipeline - Replace Nullable Types Transformer",
+            "Categorical Pipeline - Imputer",
+            "Categorical Pipeline - One Hot Encoder",
+            "Numeric Pipeline - Select Columns By Type Transformer",
+            "Numeric Pipeline - Label Encoder",
+            "Numeric Pipeline - Replace Nullable Types Transformer",
+            "Numeric Pipeline - Imputer",
+            "Numeric Pipeline - Select Columns Transformer",
+        ],
+    )
+    if sampler:
+        compute_order.extend([sampler])
+    compute_order.append("Random Forest Classifier")
+
     assert pipeline.component_graph.compute_order == compute_order
     assert pipeline.name == "test_pipeline"
     assert pipeline.parameters["Numeric Pipeline - Select Columns By Type Transformer"][
@@ -416,6 +440,7 @@ def test_make_split_pipeline_categorical_only(X_y_binary):
     compute_order = [
         "Select Columns Transformer",
         "Label Encoder",
+        "Replace Nullable Types Transformer",
         "Imputer",
         "One Hot Encoder",
         "Random Forest Classifier",
@@ -439,9 +464,19 @@ def test_select_cat_cols(
     X, y = X_y_categorical_classification
     X.ww.init()
     cat_cols = list(X.ww.select("categorical").columns)
-    mock_get_names.return_value = ["0", "1", "2", "Sex_male", "Embarked_S"]
+    mock_get_names.return_value = [
+        "0",
+        "1",
+        "2",
+        "Sex_male",
+        "Ticket_A/5 21171",
+        "C85",
+        "Embarked_S",
+    ]
     mock_get_feature_provenance.return_value = {
         "Sex": ["Sex_male"],
+        "Ticket": ["Ticket_A/5 21171"],
+        "Cabin": ["C85"],
         "Embarked": ["Embarked_S"],
     }
 
@@ -546,30 +581,22 @@ def test_default_algorithm_allow_long_running_models_next_batch(
 
 
 @pytest.mark.parametrize(
-    "automl_type",
+    "problem_type",
     [
-        ProblemTypes.TIME_SERIES_BINARY,
-        ProblemTypes.TIME_SERIES_MULTICLASS,
-        ProblemTypes.TIME_SERIES_REGRESSION,
+        "time series binary",
+        "time series multiclass",
+        "time series regression",
     ],
 )
 @patch("evalml.pipelines.components.FeatureSelector.get_names")
 def test_default_algorithm_time_series(
     mock_get_names,
-    automl_type,
+    problem_type,
     ts_data,
-    ts_data_binary,
-    ts_data_multi,
 ):
-    if automl_type == ProblemTypes.TIME_SERIES_BINARY:
-        X, y = ts_data_binary
-    elif automl_type == ProblemTypes.TIME_SERIES_MULTICLASS:
-        X, y = ts_data_multi
-    elif automl_type == ProblemTypes.TIME_SERIES_REGRESSION:
-        X, y = ts_data
+    X, _, y = ts_data(problem_type=problem_type)
 
     mock_get_names.return_value = ["0", "1", "2"]
-    problem_type = ProblemTypes.TIME_SERIES_REGRESSION
     sampler_name = None
     search_parameters = {
         "pipeline": {
@@ -636,36 +663,27 @@ def test_default_algorithm_time_series(
 
 
 @pytest.mark.parametrize(
-    "automl_type",
+    "problem_type",
     [
-        ProblemTypes.TIME_SERIES_BINARY,
-        ProblemTypes.TIME_SERIES_MULTICLASS,
-        ProblemTypes.TIME_SERIES_REGRESSION,
+        "time series binary",
+        "time series multiclass",
+        "time series regression",
     ],
 )
 @patch("evalml.pipelines.components.FeatureSelector.get_names")
 def test_default_algorithm_time_series_known_in_advance(
     mock_get_names,
-    automl_type,
+    problem_type,
     ts_data,
-    ts_data_binary,
-    ts_data_multi,
 ):
-    if automl_type == ProblemTypes.TIME_SERIES_BINARY:
-        X, y = ts_data_binary
-    elif automl_type == ProblemTypes.TIME_SERIES_MULTICLASS:
-        X, y = ts_data_multi
-    elif automl_type == ProblemTypes.TIME_SERIES_REGRESSION:
-        X, y = ts_data
+    X, _, y = ts_data(problem_type=problem_type)
 
-    X.ww.init()
     X.ww["email"] = pd.Series(["foo@foo.com"] * X.shape[0], index=X.index)
     X.ww["category"] = pd.Series(["a"] * X.shape[0], index=X.index)
     X.ww.set_types({"email": "EmailAddress", "category": "Categorical"})
     known_in_advance = ["email", "category"]
 
     mock_get_names.return_value = ["0", "1", "2"]
-    problem_type = ProblemTypes.TIME_SERIES_REGRESSION
     sampler_name = None
     search_parameters = {
         "pipeline": {
@@ -699,7 +717,7 @@ def test_default_algorithm_time_series_known_in_advance(
         )
         assert pipeline.parameters[
             "Not Known In Advance Pipeline - Select Columns Transformer"
-        ]["columns"] == ["features", "date"]
+        ]["columns"] == ["feature", "date"]
     add_result(algo, first_batch)
 
     second_batch = algo.next_batch()
@@ -714,7 +732,7 @@ def test_default_algorithm_time_series_known_in_advance(
         )
         assert pipeline.parameters[
             "Not Known In Advance Pipeline - Select Columns Transformer"
-        ]["columns"] == ["features", "date"]
+        ]["columns"] == ["feature", "date"]
     add_result(algo, second_batch)
 
     final_batch = algo.next_batch()
@@ -734,7 +752,7 @@ def test_default_algorithm_time_series_known_in_advance(
         )
         assert pipeline.parameters[
             "Not Known In Advance Pipeline - Select Columns Transformer"
-        ]["columns"] == ["features", "date"]
+        ]["columns"] == ["feature", "date"]
     add_result(algo, final_batch)
 
     long_explore = algo.next_batch()
@@ -756,14 +774,18 @@ def test_default_algorithm_time_series_known_in_advance(
 @pytest.mark.parametrize(
     "automl_type",
     [
-        ProblemTypes.TIME_SERIES_BINARY,
-        ProblemTypes.TIME_SERIES_MULTICLASS,
-        ProblemTypes.TIME_SERIES_REGRESSION,
+        "time series binary",
+        "time series multiclass",
+        "time series regression",
     ],
 )
 @patch("evalml.pipelines.components.FeatureSelector.get_names")
-def test_default_algorithm_time_series_ensembling(mock_get_names, automl_type, ts_data):
-    X, y = ts_data
+def test_default_algorithm_time_series_ensembling(
+    mock_get_names,
+    automl_type,
+    ts_data,
+):
+    X, _, y = ts_data()
     with pytest.raises(
         ValueError,
         match="Ensembling is not available for time series problems in DefaultAlgorithm.",
