@@ -129,6 +129,7 @@ def test_train_pipeline_trains_and_tunes_threshold(
         0,
         None,
         None,
+        {},
     )
     env = AutoMLTestEnv("binary")
     with env.test_context():
@@ -149,6 +150,7 @@ def test_train_pipeline_trains_and_tunes_threshold(
         0,
         None,
         None,
+        {},
     )
     with env.test_context():
         _ = train_pipeline(dummy_binary_pipeline, X, y, automl_config=automl_config)
@@ -161,8 +163,12 @@ def test_train_pipeline_trains_and_tunes_threshold_ts(
     ts_data,
     dummy_ts_binary_tree_classifier_pipeline_class,
 ):
-    X = pd.DataFrame(pd.date_range("1/1/21", periods=32), columns=["date"])
-    y = pd.Series([0, 1, 0, 1] * 8)
+    X, _, y = ts_data(
+        train_features_index_dt=False,
+        train_target_index_dt=False,
+        no_features=True,
+        problem_type="time series binary",
+    )
 
     params = {"gap": 1, "max_delay": 1, "forecast_horizon": 1, "time_index": "date"}
     ts_binary = dummy_ts_binary_tree_classifier_pipeline_class(
@@ -181,6 +187,7 @@ def test_train_pipeline_trains_and_tunes_threshold_ts(
         0,
         None,
         None,
+        {},
     )
     cv_pipeline, _ = train_pipeline(ts_binary, X, y, automl_config=automl_config)
     assert cv_pipeline.threshold is not None
@@ -217,6 +224,7 @@ def test_train_pipelines_cache(
         0,
         None,
         None,
+        {},
     )
     env = AutoMLTestEnv("binary")
     with env.test_context():
