@@ -13,22 +13,13 @@ from evalml.pipelines.components.utils import (
     _all_estimators_used_in_search,
     get_estimators,
 )
-from evalml.problem_types import (
-    ProblemTypes,
-    handle_problem_types,
-    is_binary,
-    is_multiclass,
-    is_regression,
-)
+from evalml.problem_types import ProblemTypes, handle_problem_types
 from evalml.problem_types.utils import is_classification
 from evalml.utils import get_random_state
 
 
 def test_estimators_feature_name_with_random_ascii(
-    X_y_binary,
-    X_y_multi,
-    X_y_regression,
-    ts_data,
+    X_y_based_on_pipeline_or_problem_type,
     helper_functions,
 ):
     for estimator_class in _all_estimators_used_in_search():
@@ -43,12 +34,7 @@ def test_estimators_feature_name_with_random_ascii(
         ]
         for problem_type in supported_problem_types:
             clf = helper_functions.safe_init_component_with_njobs_1(estimator_class)
-            if is_binary(problem_type):
-                X, y = X_y_binary
-            elif is_multiclass(problem_type):
-                X, y = X_y_multi
-            elif is_regression(problem_type):
-                X, y = X_y_regression
+            X, y = X_y_based_on_pipeline_or_problem_type(problem_type)
 
             X = get_random_state(clf.random_seed).random(
                 (X.shape[0], len(string.printable)),
@@ -138,9 +124,8 @@ def test_all_estimators_check_fit_input_type_regression(
 
 
 def test_estimator_predict_output_type(X_y_binary, helper_functions):
-    X_np, y_np = X_y_binary
-    assert isinstance(X_np, np.ndarray)
-    assert isinstance(y_np, np.ndarray)
+    X, y = X_y_binary
+    X_np, y_np = X.values, y.values
 
     y_list = list(y_np)
     X_df_no_col_names = pd.DataFrame(X_np)
