@@ -8,13 +8,14 @@ import woodwork as ww
 from pandas.testing import assert_frame_equal
 from woodwork.logical_types import (
     Boolean,
+    BooleanNullable,
     Categorical,
     Double,
-    Integer,
     NaturalLanguage,
 )
 
 from evalml.pipelines.components import Imputer
+from evalml.pipelines.components.transformers.imputers import KNNImputer, SimpleImputer
 
 
 def test_invalid_strategy_parameters():
@@ -69,14 +70,36 @@ def test_imputer_init(
     }
     expected_hyperparameters = {
         "categorical_impute_strategy": ["most_frequent"],
-        "numeric_impute_strategy": ["mean", "median", "most_frequent"],
-        "boolean_impute_strategy": ["most_frequent"],
+        "numeric_impute_strategy": ["mean", "median", "most_frequent", "knn"],
+        "boolean_impute_strategy": ["most_frequent", "knn"],
     }
     assert imputer.name == "Imputer"
     assert imputer.parameters == expected_parameters
     assert imputer.hyperparameter_ranges == expected_hyperparameters
 
 
+@pytest.mark.parametrize("categorical_impute_strategy", ["most_frequent", "constant"])
+def test_knn_as_input(categorical_impute_strategy):
+    imputer = Imputer(
+        categorical_impute_strategy=categorical_impute_strategy,
+        numeric_impute_strategy="knn",
+        boolean_impute_strategy="knn",
+    )
+    assert isinstance(imputer._categorical_imputer, SimpleImputer)
+    assert isinstance(imputer._numeric_imputer, KNNImputer)
+    assert isinstance(imputer._boolean_imputer, KNNImputer)
+
+    expected_numeric_parameters = {
+        "number_neighbors": 3,
+    }
+    expected_boolean_parameters = {
+        "number_neighbors": 1,
+    }
+
+    assert imputer._numeric_imputer.parameters == expected_numeric_parameters
+    assert imputer._boolean_imputer.parameters == expected_boolean_parameters
+
+
 def test_numeric_only_input(imputer_test_data):
     X = imputer_test_data[
         ["int col", "float col", "int with nan", "float with nan", "all nan"]
@@ -88,15 +111,16 @@ def test_numeric_only_input(imputer_test_data):
     expected = pd.DataFrame(
         {
             "int col": [0, 1, 2, 0, 3] * 4,
-            "float col": [0.0, 1.0, 0.0, -2.0, 5.0] * 4,
+            "float col": [0.1, 1.0, 0.0, -2.0, 5.0] * 4,
             "int with nan": [0.5, 1.0, 0.0, 0.0, 1.0] * 4,
-            "float with nan": [0.0, 1.0, 0, -1.0, 0.0] * 4,
+            "float with nan": [0.3, 1.0, 0.15, -1.0, 0.0] * 4,
         },
     )
     assert_frame_equal(transformed, expected, check_dtype=False)
 
-    imputer = Imputer()
+    imputer = Imputer(numeric_impute_strategy="median")
     transformed = imputer.fit_transform(X, y)
+    expected["float with nan"] = [0.3, 1.0, 0.15, -1.0, 0.0] * 4
     assert_frame_equal(transformed, expected, check_dtype=False)
 
 
@@ -132,7 +156,6 @@ def test_categorical_only_input(imputer_test_data):
             ),
             "bool col with nan": pd.Series(
                 [True, True, False, True, True] * 4,
-                dtype="category",
             ),
         },
     )
@@ -158,21 +181,20 @@ def test_categorical_and_numeric_input(imputer_test_data):
             ),
             "int col": [0, 1, 2, 0, 3] * 4,
             "object col": pd.Series(["b", "b", "a", "c", "d"] * 4, dtype="category"),
-            "float col": [0.0, 1.0, 0.0, -2.0, 5.0] * 4,
+            "float col": [0.1, 1.0, 0.0, -2.0, 5.0] * 4,
             "bool col": [True, False, False, True, True] * 4,
             "categorical with nan": pd.Series(
                 ["0", "1", "0", "0", "3"] * 4,
                 dtype="category",
             ),
             "int with nan": [0.5, 1.0, 0.0, 0.0, 1.0] * 4,
-            "float with nan": [0.0, 1.0, 0, -1.0, 0.0] * 4,
+            "float with nan": [0.3, 1.0, 0.075, -1.0, 0.0] * 4,
             "object with nan": pd.Series(
                 ["b", "b", "b", "c", "b"] * 4,
                 dtype="category",
             ),
             "bool col with nan": pd.Series(
                 [True, True, False, True, True] * 4,
-                dtype="category",
             ),
             "natural language col": pd.Series(
                 ["cats are really great", "don't", "believe", "me?", "well..."] * 4,
@@ -313,14 +335,13 @@ def test_imputer_fill_value(imputer_test_data):
                 ["fill", "1", "0", "0", "3"] * 4,
                 dtype="category",
             ),
-            "float with nan": [0.0, 1.0, -1, -1.0, 0.0] * 4,
+            "float with nan": [0.3, 1.0, -1, -1.0, 0.0] * 4,
             "object with nan": pd.Series(
                 ["b", "b", "fill", "c", "fill"] * 4,
                 dtype="category",
             ),
             "bool col with nan": pd.Series(
                 [True, True, False, True, True] * 4,
-                dtype="category",
             ),
         },
     )
@@ -511,8 +532,9 @@ def test_imputer_all_bool_return_original(data_type, make_data_type):
 @pytest.mark.parametrize("data_type", ["pd", "ww"])
 def test_imputer_bool_dtype_object(data_type, make_data_type):
     X = pd.DataFrame([True, np.nan, False, np.nan, True] * 4)
+    X.ww.init(logical_types={0: BooleanNullable})
     y = pd.Series([1, 0, 0, 1, 0] * 4)
-    X_expected_arr = pd.DataFrame([True, True, False, True, True] * 4, dtype="category")
+    X_expected_arr = pd.DataFrame([True, True, False, True, True] * 4, dtype="bool")
     X = make_data_type(data_type, X)
     y = make_data_type(data_type, y)
     imputer = Imputer()
@@ -532,16 +554,18 @@ def test_imputer_multitype_with_one_bool(data_type, make_data_type):
             ),
         },
     )
+    X_multi.ww.init(
+        logical_types={"bool with nan": BooleanNullable, "bool no nan": Boolean},
+    )
     y = pd.Series([1, 0, 0, 1, 0] * 4)
     X_multi_expected_arr = pd.DataFrame(
         {
             "bool with nan": pd.Series(
                 [True, False, False, False, False] * 4,
-                dtype="category",
+                dtype="bool",
             ),
             "bool no nan": pd.Series(
                 [False, False, False, False, True] * 4,
-                dtype=bool,
             ),
         },
     )
@@ -563,7 +587,9 @@ def test_imputer_int_preserved():
         transformed,
         pd.DataFrame(pd.Series([1, 2, 11, 14 / 3])),
     )
-    assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {0: Double}
+    assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {
+        0: Double,
+    }
 
     X = pd.DataFrame(pd.Series([1, 2, 3, np.nan]))
     imputer = Imputer(numeric_impute_strategy="mean")
@@ -573,7 +599,9 @@ def test_imputer_int_preserved():
         pd.DataFrame(pd.Series([1, 2, 3, 2])),
         check_dtype=False,
     )
-    assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {0: Double}
+    assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {
+        0: Double,
+    }
 
     X = pd.DataFrame(pd.Series([1, 2, 3, 4], dtype="int"))
     imputer = Imputer(numeric_impute_strategy="mean")
@@ -583,7 +611,7 @@ def test_imputer_int_preserved():
         pd.DataFrame(pd.Series([1, 2, 3, 4])),
         check_dtype=False,
     )
-    assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {0: Integer}
+    assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {0: Double}
 
 
 @pytest.mark.parametrize("null_type", ["pandas_na", "numpy_nan", "python_none"])
@@ -594,25 +622,21 @@ def test_imputer_bool_preserved(test_case, null_type):
             null_type
         ]
         X = pd.DataFrame(pd.Series([True, False, True, null_type] * 4))
+        X.ww.init(logical_types={0: BooleanNullable})
         expected = pd.DataFrame(
-            pd.Series([True, False, True, True] * 4, dtype="category"),
+            pd.Series([True, False, True, True] * 4, dtype="bool"),
         )
-        expected_ww_dtype = Categorical
-        check_dtype = True
     elif test_case == "boolean_without_null":
         X = pd.DataFrame(pd.Series([True, False, True, False] * 4))
         expected = pd.DataFrame(pd.Series([True, False, True, False] * 4))
-        expected_ww_dtype = Boolean
-        check_dtype = False
     imputer = Imputer(categorical_impute_strategy="most_frequent")
     transformed = imputer.fit_transform(X)
     pd.testing.assert_frame_equal(
         transformed,
         expected,
-        check_dtype=check_dtype,
     )
     assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {
-        0: expected_ww_dtype,
+        0: Boolean,
     }
 
 
@@ -662,20 +686,20 @@ def test_imputer_woodwork_custom_overrides_returned_by_components(
         "bool col": imputer_test_data[["bool col"]],
     }[data]
     logical_type = {
-        "Integer": Integer,
+        "Integer": Double,
         "Double": Double,
         "Categorical": Categorical,
         "NaturalLanguage": NaturalLanguage,
         "Boolean": Boolean,
     }[logical_type]
-    y = pd.Series([1, 2, 1])
-
-    # Column with Nans to boolean used to fail. Now it doesn't but it should.
     if has_nan == "has_nan" and logical_type == Boolean:
-        return
+        logical_type = BooleanNullable
+    y = pd.Series([1, 2, 1])
     try:
         X = X_df.copy()
-        if has_nan == "has_nan":
+        if has_nan == "has_nan" and logical_type == BooleanNullable:
+            X.iloc[len(X_df) - 1, 0] = None
+        elif has_nan == "has_nan":
             X.iloc[len(X_df) - 1, 0] = np.nan
         X.ww.init(logical_types={data: logical_type})
     except ww.exceptions.TypeConversionError:
@@ -685,7 +709,11 @@ def test_imputer_woodwork_custom_overrides_returned_by_components(
     imputer.fit(X, y)
     transformed = imputer.transform(X, y)
     assert isinstance(transformed, pd.DataFrame)
-    if numeric_impute_strategy == "most_frequent":
+    if logical_type == BooleanNullable:
+        assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {
+            data: Boolean,
+        }
+    elif numeric_impute_strategy == "most_frequent":
         assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {
             data: logical_type,
         }
