@@ -3,6 +3,7 @@ import inspect
 import numpy as np
 import pandas as pd
 import pytest
+from pandas.testing import assert_frame_equal
 
 from evalml.exceptions import MissingComponentError
 from evalml.model_family import ModelFamily
@@ -15,12 +16,15 @@ from evalml.pipelines.components import ComponentBase, RandomForestClassifier
 from evalml.pipelines.components.utils import (
     _all_estimators,
     all_components,
+    drop_natural_language_columns,
     estimator_unable_to_handle_nans,
     handle_component_class,
     make_balancing_dictionary,
     scikit_learn_wrapped_estimator,
+    set_boolean_columns_to_categorical,
 )
 from evalml.problem_types import ProblemTypes
+from evalml.utils.woodwork_utils import infer_feature_types
 
 binary = pd.Series([0] * 800 + [1] * 200)
 multiclass = pd.Series([0] * 800 + [1] * 150 + [2] * 50)
@@ -46,6 +50,7 @@ all_requirements_set = set(
         "Extra Trees Regressor",
         "Imputer",
         "KNN Classifier",
+        "KNN Imputer",
         "LSA Transformer",
         "Label Encoder",
         "Linear Discriminant Analysis Transformer",
@@ -82,7 +87,7 @@ all_requirements_set = set(
         "LightGBM Classifier",
         "LightGBM Regressor",
         "Oversampler",
-        "Polynomial Detrender",
+        "Polynomial Decomposer",
         "Prophet Regressor",
         "Target Encoder",
         "Vowpal Wabbit Binary Classifier",
@@ -149,7 +154,7 @@ def test_scikit_learn_wrapper_invalid_problem_type():
         scikit_learn_wrapped_estimator(evalml_pipeline)
 
 
-def test_scikit_learn_wrapper(X_y_binary, X_y_multi, X_y_regression, ts_data):
+def test_scikit_learn_wrapper(X_y_binary, X_y_multi, X_y_regression):
     for estimator in [
         estimator
         for estimator in _all_estimators()
@@ -229,3 +234,73 @@ def test_estimator_unable_to_handle_nans():
         match="`estimator_class` must have a `model_family` attribute.",
     ):
         estimator_unable_to_handle_nans("error")
+
+
+def test_drop_natural_languages():
+    X = pd.DataFrame(
+        {
+            "bool with nan": pd.Series(
+                [True, pd.NA, False, pd.NA, False],
+                dtype="boolean",
+            ),
+            "bool no nan": pd.Series([False, False, False, False, True], dtype=bool),
+            "natural language": pd.Series(["asdf", "fdsa", "a", "b", "c"]),
+        },
+    )
+    X = infer_feature_types(X)
+    X.ww.set_types(
+        logical_types={
+            "natural language": "natural_language",
+        },
+    )
+    X_t, dropped_cols = drop_natural_language_columns(X)
+    expected_dropped = ["natural language"]
+    assert expected_dropped == dropped_cols
+    assert len(X_t.columns) == 2
+    X_expected = pd.DataFrame(
+        {
+            "bool with nan": pd.Series(
+                [True, pd.NA, False, pd.NA, False],
+                dtype="boolean",
+            ),
+            "bool no nan": pd.Series([False, False, False, False, True], dtype=bool),
+        },
+    )
+    assert_frame_equal(X_expected, X_t)
+
+
+def test_set_boolean_columns_to_categorical():
+    X = pd.DataFrame(
+        {
+            "bool with nan": pd.Series(
+                [True, pd.NA, False, pd.NA, False],
+                dtype="boolean",
+            ),
+            "bool no nan": pd.Series([False, False, False, False, True], dtype=bool),
+            "natural language": pd.Series(["asdf", "fdsa", "a", "b", "c"]),
+        },
+    )
+    X_e = pd.DataFrame(
+        {
+            "bool no nan": pd.Series([False, False, False, False, True], dtype=bool),
+        },
+    )
+    X_e = infer_feature_types(X_e)
+    X_e.ww.set_types(
+        logical_types={
+            "bool no nan": "Categorical",
+        },
+    )
+    X = infer_feature_types(X)
+    assert len(X.ww.select(["Categorical"]) == 0)
+
+    X = set_boolean_columns_to_categorical(X)
+
+    assert len(X.ww.select(["Categorical"]).columns) == 1
+    assert len(X.ww.select(["Categorical"]) == 5)
+
+    assert_frame_equal(
+        X.ww.select(["Categorical"]),
+        X_e.ww.select(["Categorical"]),
+        check_dtype=False,
+    )
