@@ -2,9 +2,7 @@ import numpy as np
 import pytest
 
 from evalml.model_family import ModelFamily
-from evalml.pipelines.components.estimators.regressors import (
-    VowpalWabbitRegressor,
-)
+from evalml.pipelines.components.estimators.regressors import VowpalWabbitRegressor
 from evalml.problem_types import ProblemTypes
 
 
@@ -30,7 +28,10 @@ def test_vw_parameters():
     assert vw.parameters == expected_parameters
 
     vw = VowpalWabbitRegressor(
-        learning_rate=0.1, decay_learning_rate=1.0, power_t=0.1, passes=2
+        learning_rate=0.1,
+        decay_learning_rate=1.0,
+        power_t=0.1,
+        passes=2,
     )
     expected_parameters = {
         "learning_rate": 0.1,
@@ -50,7 +51,10 @@ def test_vw_fit_predict(X_y_regression, vw):
     y_pred = vw_regressor.predict(X)
 
     clf = vw.VWRegressor(
-        learning_rate=0.5, decay_learning_rate=1.0, power_t=0.5, passes=1
+        learning_rate=0.5,
+        decay_learning_rate=1.0,
+        power_t=0.5,
+        passes=1,
     )
     clf.fit(X, y)
     y_pred_sk = clf.predict(X)
