@@ -37,6 +37,8 @@ from evalml.preprocessing import load_data
 from evalml.problem_types import (
     ProblemTypes,
     handle_problem_types,
+    is_binary,
+    is_multiclass,
     is_regression,
     is_time_series,
 )
@@ -104,6 +106,17 @@ def get_test_data_with_or_without_primary_key():
                 X_dict["col_1_id"] = [1, 1, 2, 3]
             X = pd.DataFrame.from_dict(X_dict)
 
+        elif input_type == "double":
+            X_dict = {
+                "col_1_id": [0.0, 1.0, 2.0, 3.0],
+                "col_2": [2, 3, 4, 5],
+                "col_3_id": [1, 1, 2, 3],
+                "col_5": [0, 0, 1, 2],
+            }
+            if not has_primary_key:
+                X_dict["col_1_id"] = [1.0, 1.0, 2.0, 3.0]
+            X = pd.DataFrame.from_dict(X_dict)
+
         elif input_type == "string":
             X_dict = {
                 "col_1_id": ["a", "b", "c", "d"],
@@ -270,25 +283,26 @@ def get_test_data_from_configuration():
 
 
 @pytest.fixture
-def get_ts_X_y():
+def ts_data():
     def _get_X_y(
-        train_features_index_dt,
-        train_target_index_dt,
-        train_none,
-        datetime_feature,
-        no_features,
-        test_features_index_dt,
+        train_features_index_dt=True,
+        train_target_index_dt=True,
+        train_none=False,
+        datetime_feature=True,
+        no_features=False,
+        test_features_index_dt=True,
+        freq="D",
+        problem_type="time series regression",
     ):
         X = pd.DataFrame(index=[i + 1 for i in range(50)])
-        dates = pd.date_range("1/1/21", periods=50)
-        feature = pd.Series([1, 5, 2] * 10 + [3, 1] * 10, index=X.index)
+        dates = pd.date_range("1/1/21", periods=50, freq=freq)
+        feature = pd.Series([1, 4, 2] * 10 + [3, 1] * 10, index=X.index)
         y = pd.Series([1, 2, 3, 4, 5, 6, 5, 4, 3, 2] * 5)
-        X.ww.init()
-        y = ww.init_series(y)
 
-        X_train = X.ww.iloc[:40]
-        X_test = X.ww.iloc[40:]
-        y_train = y.ww.iloc[:40]
+        X_train = X.iloc[:40]
+        X_test = X.iloc[40:]
+        y_train = y.iloc[:40]
+        logical_types = {}
 
         if train_features_index_dt:
             X_train.index = dates[:40]
@@ -297,13 +311,24 @@ def get_ts_X_y():
         if test_features_index_dt:
             X_test.index = dates[40:]
         if not no_features:
-            X_train.ww["Feature"] = pd.Series(feature[:40].values, index=X_train.index)
-            X_test.ww["Feature"] = pd.Series(feature[40:].values, index=X_test.index)
-            if datetime_feature:
-                X_train.ww["Dates"] = pd.Series(dates[:40].values, index=X_train.index)
-                X_test.ww["Dates"] = pd.Series(dates[40:].values, index=X_test.index)
+            X_train["feature"] = pd.Series(feature[:40].values, index=X_train.index)
+            X_test["feature"] = pd.Series(feature[40:].values, index=X_test.index)
+            logical_types["feature"] = "integer"
+        if datetime_feature:
+            X_train["date"] = pd.Series(dates[:40].values, index=X_train.index)
+            X_test["date"] = pd.Series(dates[40:].values, index=X_test.index)
+            logical_types["date"] = "datetime"
         if train_none:
             X_train = None
+        if is_binary(problem_type):
+            y_train = y_train % 2
+        if is_multiclass(problem_type):
+            y_train = y_train % 3
+
+        if X_train is not None:
+            X_train.ww.init(logical_types=logical_types)
+        X_test.ww.init(logical_types=logical_types)
+        y_train.ww.init(logical_type="integer")
 
         return X_train, X_test, y_train
 
@@ -731,7 +756,9 @@ def X_y_binary():
         n_redundant=2,
         random_state=0,
     )
-
+    X = pd.DataFrame(X)
+    X.ww.init(logical_types={col: "double" for col in X.columns})
+    y = ww.init_series(pd.Series(y), logical_type="integer")
     return X, y
 
 
@@ -755,6 +782,9 @@ def X_y_regression():
         n_informative=3,
         random_state=0,
     )
+    X = pd.DataFrame(X)
+    X.ww.init(logical_types={col: "double" for col in X.columns})
+    y = ww.init_series(pd.Series(y), logical_type="double")
     return X, y
 
 
@@ -768,6 +798,9 @@ def X_y_multi():
         n_redundant=2,
         random_state=0,
     )
+    X = pd.DataFrame(X)
+    X.ww.init(logical_types={col: "double" for col in X.columns})
+    y = ww.init_series(pd.Series(y), logical_type="integer")
     return X, y
 
 
@@ -781,6 +814,18 @@ def X_y_categorical_regression():
 
     # add categorical dtype
     X["smoker"] = X["smoker"].astype("category")
+
+    X.ww.init(
+        logical_types={
+            "total_bill": "double",
+            "sex": "categorical",
+            "smoker": "categorical",
+            "day": "categorical",
+            "time": "categorical",
+            "size": "integer",
+        },
+    )
+    y.ww.init(logical_type="double")
     return X, y
 
 
@@ -791,6 +836,21 @@ def X_y_categorical_classification():
 
     y = titanic["Survived"]
     X = titanic.drop(["Survived", "Name"], axis=1)
+    X.ww.init(
+        logical_types={
+            "PassengerId": "integer",
+            "Pclass": "integer",
+            "Sex": "categorical",
+            "Age": "double",
+            "SibSp": "integer",
+            "Parch": "integer",
+            "Ticket": "categorical",
+            "Fare": "double",
+            "Cabin": "categorical",
+            "Embarked": "categorical",
+        },
+    )
+    y.ww.init(logical_type="integer")
     return X, y
 
 
@@ -801,6 +861,9 @@ def X_y_based_on_pipeline_or_problem_type(X_y_binary, X_y_multi, X_y_regression)
             ProblemTypes.BINARY: "binary",
             ProblemTypes.MULTICLASS: "multiclass",
             ProblemTypes.REGRESSION: "regression",
+            ProblemTypes.TIME_SERIES_BINARY: "binary",
+            ProblemTypes.TIME_SERIES_MULTICLASS: "multiclass",
+            ProblemTypes.TIME_SERIES_REGRESSION: "regression",
         }
         pipeline_classes = {
             BinaryClassificationPipeline: "binary",
@@ -845,29 +908,29 @@ def text_df():
 
 
 @pytest.fixture
-def ts_data():
+def ts_data_long():
     X, y = pd.DataFrame(
         {
-            "features": range(101, 132),
-            "date": pd.date_range("2020-10-01", "2020-10-31"),
+            "features": range(101, 193),
+            "date": pd.date_range("2020-10-01", "2020-12-31"),
         },
-    ), pd.Series(range(1, 32))
-    y.index = pd.date_range("2020-10-01", "2020-10-31")
-    X.index = pd.date_range("2020-10-01", "2020-10-31")
+    ), pd.Series(range(1, 93))
+    y.index = pd.date_range("2020-10-01", "2020-12-31")
+    X.index = pd.date_range("2020-10-01", "2020-12-31")
+    return X, None, y
+
+
+@pytest.fixture
+def ts_data_quadratic_trend(ts_data):
+    X, _, y = ts_data()
+    y = y**2
     return X, y
 
 
 @pytest.fixture
-def ts_data_binary(ts_data):
-    X, y = ts_data
-    y = y % 2
-    return X, y
-
-
-@pytest.fixture
-def ts_data_multi(ts_data):
-    X, y = ts_data
-    y = y % 3
+def ts_data_cubic_trend(ts_data):
+    X, _, y = ts_data()
+    y = y**3
     return X, y
 
 
@@ -1127,7 +1190,7 @@ def dummy_ts_binary_tree_classifier_pipeline_class():
 
     class MockBinaryClassificationPipeline(TimeSeriesBinaryClassificationPipeline):
         estimator = dec_tree_classifier
-        component_graph = [estimator]
+        component_graph = ["DateTime Featurizer", estimator]
 
         def __init__(
             self,
@@ -1342,7 +1405,6 @@ def fitted_decision_tree_classification_pipeline(X_y_categorical_classification)
         },
     )
     X, y = X_y_categorical_classification
-    X.ww.init(logical_types={"Ticket": "categorical", "Cabin": "categorical"})
     pipeline.fit(X, y)
     return pipeline
 
@@ -1481,8 +1543,19 @@ def fitted_tree_estimators(tree_estimators, X_y_binary, X_y_regression):
     est_clf, est_reg = tree_estimators
     X_b, y_b = X_y_binary
     X_r, y_r = X_y_regression
-    X_b = pd.DataFrame(X_b, columns=[f"Testing_{col}" for col in range(len(X_b[0]))])
-    X_r = pd.DataFrame(X_r, columns=[f"Testing_{col}" for col in range(len(X_r[0]))])
+
+    b_cols = [f"Testing_{col}" for col in X_b.columns]
+    X_b = pd.DataFrame(X_b)
+    X_b.columns = b_cols
+    X_b.ww.init(logical_types={col: "double" for col in X_b.columns})
+
+    r_cols = [f"Testing_{col}" for col in X_r.columns]
+    X_r = pd.DataFrame(
+        X_r,
+    )
+    X_r.columns = r_cols
+    X_r.ww.init(logical_types={col: "double" for col in X_r.columns})
+
     est_clf.fit(X_b, y_b)
     est_reg.fit(X_r, y_r)
     return est_clf, est_reg
@@ -2067,7 +2140,7 @@ def dummy_data_check_validate_output_errors():
 
 @pytest.fixture
 def imputer_test_data():
-    return pd.DataFrame(
+    X = pd.DataFrame(
         {
             "dates": pd.date_range("01-01-2022", periods=20),
             "categorical col": pd.Series(
@@ -2076,14 +2149,14 @@ def imputer_test_data():
             ),
             "int col": [0, 1, 2, 0, 3] * 4,
             "object col": ["b", "b", "a", "c", "d"] * 4,
-            "float col": [0.0, 1.0, 0.0, -2.0, 5.0] * 4,
+            "float col": [0.1, 1.0, 0.0, -2.0, 5.0] * 4,
             "bool col": [True, False, False, True, True] * 4,
             "categorical with nan": pd.Series(
                 [np.nan, "1", "0", "0", "3"] * 4,
                 dtype="category",
             ),
             "int with nan": [np.nan, 1, 0, 0, 1] * 4,
-            "float with nan": [0.0, 1.0, np.nan, -1.0, 0.0] * 4,
+            "float with nan": [0.3, 1.0, np.nan, -1.0, 0.0] * 4,
             "object with nan": ["b", "b", np.nan, "c", np.nan] * 4,
             "bool col with nan": pd.Series(
                 [True, np.nan, False, np.nan, True] * 4,
@@ -2100,3 +2173,22 @@ def imputer_test_data():
             ),
         },
     )
+    X.ww.init(
+        logical_types={
+            "dates": "datetime",
+            "categorical col": "categorical",
+            "int col": "integer",
+            "object col": "categorical",
+            "float col": "double",
+            "bool col": "boolean",
+            "categorical with nan": "categorical",
+            "int with nan": "IntegerNullable",
+            "float with nan": "double",
+            "object with nan": "categorical",
+            "bool col with nan": "BooleanNullable",
+            "all nan": "unknown",
+            "all nan cat": "categorical",
+            "natural language col": "NaturalLanguage",
+        },
+    )
+    return X
