@@ -54,6 +54,14 @@ def data_checks_input_dataframe():
         },
     )
     X["nan_dt_col"][0] = None
+    X.ww.init(
+        logical_types={
+            "lots_of_null": "categorical",
+            "natural_language_nan": "NaturalLanguage",
+            "nullable_integer": "IntegerNullable",
+            "nullable_bool": "BooleanNullable",
+        },
+    )
     return X
 
 
@@ -277,14 +285,6 @@ def test_default_data_checks_classification(input_type, data_checks_input_datafr
 
     y = pd.Series([0, 1, np.nan, 1, 0])
     y_multiclass = pd.Series([0, 1, np.nan, 2, 0])
-    X.ww.init(
-        logical_types={
-            "lots_of_null": "categorical",
-            "natural_language_nan": "NaturalLanguage",
-            "nullable_integer": "IntegerNullable",
-            "nullable_bool": "BooleanNullable",
-        },
-    )
     if input_type == "ww":
         y = ww.init_series(y)
         y_multiclass = ww.init_series(y_multiclass)
@@ -295,7 +295,7 @@ def test_default_data_checks_classification(input_type, data_checks_input_datafr
     )
     imbalance = [
         DataCheckError(
-            message="The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: [0.0, 1.0]",
+            message="The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: [0, 1]",
             data_check_name="ClassImbalanceDataCheck",
             message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
             details={"target_values": [0.0, 1.0]},
@@ -319,7 +319,7 @@ def test_default_data_checks_classification(input_type, data_checks_input_datafr
     # multiclass
     imbalance = [
         DataCheckError(
-            message="The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: [0.0, 1.0, 2.0]",
+            message="The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: [0, 1, 2]",
             data_check_name="ClassImbalanceDataCheck",
             message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
             details={"target_values": [0.0, 1.0, 2.0]},
@@ -379,13 +379,6 @@ def test_default_data_checks_regression(input_type, data_checks_input_dataframe)
 
     y = pd.Series([0.3, 100.0, np.nan, 1.0, 0.2])
     y_no_variance = pd.Series([5] * 5)
-    X.ww.init(
-        logical_types={
-            "lots_of_null": "categorical",
-            "natural_language_nan": "NaturalLanguage",
-            "nullable_bool": "BooleanNullable",
-        },
-    )
     if input_type == "ww":
         y = ww.init_series(y)
         y_no_variance = ww.init_series(y_no_variance)
@@ -511,6 +504,14 @@ def test_default_data_checks_null_rows():
                 ),
             ],
         ).to_dict(),
+        DataCheckError(
+            message="Target is unsupported integer_nullable type. Valid Woodwork "
+            "logical types include: integer, double",
+            data_check_name="TargetDistributionDataCheck",
+            message_code=DataCheckMessageCode.TARGET_UNSUPPORTED_TYPE,
+            details={"unsupported_type": "integer_nullable"},
+            action_options=[],
+        ).to_dict(),
     ]
     validation_messages = data_checks.validate(X, y)
     validation_messages[0]["details"]["pct_null_cols"] = SeriesWrap(
@@ -563,7 +564,7 @@ def test_default_data_checks_across_problem_types(problem_type):
     assert data_check_classes == default_data_check_list
 
 
-def test_default_data_checks_missing_problem_configuration_for_time_series(ts_data):
+def test_default_data_checks_missing_problem_configuration_for_time_series():
     with pytest.raises(
         ValueError,
         match="problem_configuration cannot be None for time series problems!",
@@ -696,7 +697,7 @@ def test_data_checks_raises_value_errors_on_init(
     ],
 )
 def test_errors_warnings_in_invalid_target_data_check(objective, ts_data):
-    X, y = ts_data
+    X, _, y = ts_data()
     y[0] = -1
     y = pd.Series(y)
     details = {"Count of offending values": sum(val <= 0 for val in y.values.flatten())}
