@@ -14,6 +14,9 @@ from evalml.data_checks import (
 
 datetime_format_check_name = DateTimeFormatDataCheck.name
 
+WINDOW_LENGTH = 4
+THRESHOLD = 0.4
+
 
 def get_uneven_error(col_name, ww_payload):
     error = DataCheckError(
@@ -37,7 +40,7 @@ def get_uneven_error(col_name, ww_payload):
                     },
                 },
                 metadata={"is_target": True},
-            )
+            ),
         ],
     ).to_dict()
     return error
@@ -45,11 +48,14 @@ def get_uneven_error(col_name, ww_payload):
 
 @pytest.mark.parametrize("input_type", ["pd", "ww"])
 @pytest.mark.parametrize(
-    "issue", ["redundant", "missing", "uneven", "type_errors", None]
+    "issue",
+    ["redundant", "missing", "uneven", "type_errors", None],
 )
 @pytest.mark.parametrize("datetime_loc", [1, "X_index", "y_index"])
 def test_datetime_format_data_check_typeerror_uneven_intervals(
-    issue, input_type, datetime_loc
+    issue,
+    input_type,
+    datetime_loc,
 ):
     X, y = pd.DataFrame({"features": range(30)}), pd.Series(range(30))
 
@@ -61,17 +67,26 @@ def test_datetime_format_data_check_typeerror_uneven_intervals(
     if issue == "missing":
         # Skips 2021-01-25 and starts again at 2021-01-27, skipping a date and triggering the error
         dates = pd.date_range("2021-01-01", periods=25).append(
-            pd.date_range("2021-01-27", periods=5)
+            pd.date_range("2021-01-27", periods=5),
         )
     if issue == "uneven":
-        dates = pd.DatetimeIndex(
-            pd.date_range("2021-01-01", periods=6).append(
-                pd.date_range("2021-01-07", periods=24, freq="H")
-            )
+        dates_1 = pd.date_range("2015-01-01", periods=5, freq="D")
+        dates_2 = pd.date_range("2015-01-08", periods=3, freq="D")
+        dates_3 = pd.DatetimeIndex(["2015-01-12"])
+        dates_4 = pd.date_range("2015-01-15", periods=5, freq="D")
+        dates_5 = pd.date_range("2015-01-22", periods=5, freq="D")
+        dates_6 = pd.date_range("2015-01-29", periods=11, freq="M")
+
+        dates = (
+            dates_1.append(dates_2)
+            .append(dates_3)
+            .append(dates_4)
+            .append(dates_5)
+            .append(dates_6)
         )
     if issue == "redundant":
         dates = pd.date_range("2021-01-01", periods=29).append(
-            pd.date_range("2021-01-29", periods=1)
+            pd.date_range("2021-01-29", periods=1),
         )
 
     datetime_column = "index"
@@ -95,7 +110,7 @@ def test_datetime_format_data_check_typeerror_uneven_intervals(
                 message=f"Datetime information could not be found in the data, or was not in a supported datetime format.",
                 data_check_name=datetime_format_check_name,
                 message_code=DataCheckMessageCode.DATETIME_INFORMATION_NOT_FOUND,
-            ).to_dict()
+            ).to_dict(),
         ]
     else:
         if datetime_loc == "X_index":
@@ -104,7 +119,12 @@ def test_datetime_format_data_check_typeerror_uneven_intervals(
             dates = pd.Series(y.index)
         else:
             dates = X[datetime_column]
-        ww_payload = infer_frequency(dates, debug=True, window_length=5, threshold=0.8)
+        ww_payload = infer_frequency(
+            dates,
+            debug=True,
+            window_length=WINDOW_LENGTH,
+            threshold=THRESHOLD,
+        )
 
         col_name = datetime_loc if datetime_loc == 1 else "either index"
         if issue is None:
@@ -133,7 +153,7 @@ def test_datetime_format_data_check_typeerror_uneven_intervals(
                     message=f"No frequency could be detected in column '{col_name}', possibly due to uneven intervals.",
                     data_check_name=datetime_format_check_name,
                     message_code=DataCheckMessageCode.DATETIME_NO_FREQUENCY_INFERRED,
-                ).to_dict()
+                ).to_dict(),
             ]
 
 
@@ -201,7 +221,12 @@ def test_datetime_format_data_check_multiple_missing(n_missing):
     X["dates"] = dates
     datetime_format_check = DateTimeFormatDataCheck(datetime_column="dates")
 
-    ww_payload = infer_frequency(X["dates"], debug=True, window_length=5, threshold=0.8)
+    ww_payload = infer_frequency(
+        X["dates"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
+    )
 
     assert datetime_format_check.validate(X, y) == [
         DataCheckError(
@@ -223,7 +248,12 @@ def test_datetime_format_data_check_multiple_errors():
     y = pd.Series(range(21))
     datetime_format_check = DateTimeFormatDataCheck(datetime_column="dates")
 
-    ww_payload = infer_frequency(X["dates"], debug=True, window_length=5, threshold=0.8)
+    ww_payload = infer_frequency(
+        X["dates"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
+    )
 
     assert datetime_format_check.validate(X, y) == [
         DataCheckError(
@@ -241,7 +271,12 @@ def test_datetime_format_data_check_multiple_errors():
     )
     X = pd.DataFrame({"dates": dates})
 
-    ww_payload = infer_frequency(X["dates"], debug=True, window_length=5, threshold=0.8)
+    ww_payload = infer_frequency(
+        X["dates"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
+    )
 
     assert datetime_format_check.validate(X, y) == [
         DataCheckError(
@@ -264,7 +299,12 @@ def test_datetime_format_data_check_multiple_errors():
     )
     X = pd.DataFrame({"dates": dates})
 
-    ww_payload = infer_frequency(X["dates"], debug=True, window_length=5, threshold=0.8)
+    ww_payload = infer_frequency(
+        X["dates"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
+    )
 
     assert datetime_format_check.validate(X, y) == [
         DataCheckError(
@@ -288,7 +328,12 @@ def test_datetime_format_data_check_multiple_errors():
     )
     X = pd.DataFrame({"dates": dates})
 
-    ww_payload = infer_frequency(X["dates"], debug=True, window_length=5, threshold=0.8)
+    ww_payload = infer_frequency(
+        X["dates"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
+    )
 
     assert datetime_format_check.validate(X, y) == [
         DataCheckError(
@@ -312,7 +357,12 @@ def test_datetime_format_data_check_multiple_errors():
     )
     X = pd.DataFrame({"dates": dates})
 
-    ww_payload = infer_frequency(X["dates"], debug=True, window_length=5, threshold=0.8)
+    ww_payload = infer_frequency(
+        X["dates"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
+    )
 
     assert datetime_format_check.validate(X, y) == [
         DataCheckError(
@@ -339,7 +389,12 @@ def test_datetime_format_unusual_interval():
 
     dates = dates.drop("2021-01-21")
     X = pd.DataFrame({"dates": dates})
-    ww_payload = infer_frequency(X["dates"], debug=True, window_length=5, threshold=0.8)
+    ww_payload = infer_frequency(
+        X["dates"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
+    )
 
     expected = [
         DataCheckError(
@@ -354,7 +409,12 @@ def test_datetime_format_unusual_interval():
 
     dates = dates.append(pd.date_range(dates[-1], periods=2, freq="4D"))
     X = pd.DataFrame({"dates": dates})
-    ww_payload = infer_frequency(X["dates"], debug=True, window_length=5, threshold=0.8)
+    ww_payload = infer_frequency(
+        X["dates"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
+    )
 
     expected = [
         DataCheckError(
@@ -377,7 +437,12 @@ def test_datetime_format_nan_data_check_error():
     dates[0] = np.NaN
     X = pd.DataFrame(dates, columns=["date"])
 
-    ww_payload = infer_frequency(X["date"], debug=True, window_length=5, threshold=0.8)
+    ww_payload = infer_frequency(
+        X["date"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
+    )
 
     expected = [
         DataCheckError(
@@ -398,7 +463,12 @@ def test_datetime_format_nan_data_check_error():
 
     del expected[-1]
 
-    ww_payload = infer_frequency(X["date"], debug=True, window_length=5, threshold=0.8)
+    ww_payload = infer_frequency(
+        X["date"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
+    )
 
     expected.extend(
         [
@@ -413,7 +483,7 @@ def test_datetime_format_nan_data_check_error():
                 message_code=DataCheckMessageCode.DATETIME_IS_MISSING_VALUES,
             ).to_dict(),
             get_uneven_error("date", ww_payload),
-        ]
+        ],
     )
     assert dt_nan_check.validate(X, pd.Series()) == expected
 
@@ -428,7 +498,10 @@ def test_datetime_nan_check_ww():
     ww_input = pd.DataFrame(dates, columns=["dates"])
     ww_input.ww.init()
     ww_payload = infer_frequency(
-        ww_input["dates"], debug=True, window_length=5, threshold=0.8
+        ww_input["dates"],
+        debug=True,
+        window_length=WINDOW_LENGTH,
+        threshold=THRESHOLD,
     )
 
     expected = [
