@@ -516,17 +516,17 @@ def test_partial_dependence_more_categories_than_grid_resolution(
     assert num_cat_features == 73
 
     part_dep_ans = {
-        0.05824028901694482: 63,
-        0.1349235160940143: 1,
-        0.6353030372157324: 1,
-        0.031171284274810262: 1,
-        0.009093086236362272: 1,
-        0.33547688991040336: 1,
-        0.01746660818843149: 1,
-        0.018205973481273202: 1,
-        0.2876661156872482: 1,
-        0.015320197702897345: 1,
-        0.2821023107719306: 1,
+        0.08407392065748104: 63,
+        0.10309078422967363: 1,
+        0.07237644261749679: 1,
+        0.1291414419733119: 1,
+        0.11725464403860779: 1,
+        0.06948453894869809: 1,
+        0.08055687803593513: 1,
+        0.14807925421481405: 1,
+        0.07341294777400768: 1,
+        0.15000846543936355: 1,
+        0.07507641569899197: 1,
     }
 
     part_dep_ans_rounded = round_dict_keys(part_dep_ans)
@@ -1056,8 +1056,8 @@ def test_graph_partial_dependence_regression_and_binary_categorical(
         X, y = X_y_regression
         pipeline = linear_regression_pipeline
 
-    X = pd.DataFrame(X, columns=[str(i) for i in range(X.shape[1])])
-    y = pd.Series(y)
+    X = pd.DataFrame(X)
+    X.columns = [str(i) for i in range(X.shape[1])]
     X["categorical_column"] = pd.Series([i % 3 for i in range(X.shape[0])]).astype(
         "str",
     )
@@ -1649,8 +1649,7 @@ def test_partial_dependence_scale_error():
 def test_partial_dependence_unknown(indices, error, X_y_binary):
     # test to see if we can get partial dependence fine with a dataset that has unknown features
     X, y = X_y_binary
-    X = pd.DataFrame(X)
-    X.ww.init(logical_types={0: "unknown"})
+    X.ww.set_types({0: "unknown"})
     pl = BinaryClassificationPipeline(["Random Forest Classifier"])
     pl.fit(X, y)
     if error:
@@ -1925,8 +1924,8 @@ def test_partial_dependence_jupyter_graph_check(
     logistic_regression_binary_pipeline,
 ):
     X, y = X_y_binary
-    X = X[:20, :5]
-    y = y[:20]
+    X = X.ww.iloc[:20, :5]
+    y = y.ww.iloc[:20]
     logistic_regression_binary_pipeline.fit(X, y)
 
     jupyter_check.return_value = True
